(v1.3.8)=
### 1.3.8 {small}`2019-02-05`

- various documentation and dev process improvements
- Added {func}`~scanpy.pp.combat` function for batch effect correction {cite:p}`Johnson2006,Leek2012,Pedersen2012` {pr}`398` {smaller}`M Lange`
